inventorpy
================================

An inventory and service management application.

Usage
-----

Installation
------------

::

    pip install inventorpy

Setup development environment
-----------------------------

If you want to work on this project, you need setup your development
environment using the following commands.

::

    $ pip install pipenv
    $ pipenv install --dev
    $ pipenv shell

License
-------

"inventorpy" is licensed under the MIT license.
For more information see the LICENSE file.

Changelog
---------

0.1.0a1
~~~~~~~~~~~~~~~~~~~~~~~~~~

-  Initial release.

Contributors
------------

-  Johnny Kirchman
